@@ -1,12 +1,14 @@
 package Data::Sah::Normalize;
 
+our $AUTHORITY = 'cpan:PERLANCAR'; # AUTHORITY
+our $DATE = '2021-07-29'; # DATE
+our $DIST = 'Data-Sah-Normalize'; # DIST
+our $VERSION = '0.051'; # VERSION
+
 use 5.010001;
 use strict;
 use warnings;
 
-our $DATE = '2015-04-24'; # DATE
-our $VERSION = '0.03'; # VERSION
-
 require Exporter;
 our @ISA       = qw(Exporter);
 our @EXPORT_OK = qw(
@@ -143,7 +145,7 @@ sub normalize_schema($) {
         my $has_req = $s =~ s/\*\z//;
         $s =~ $type_re or die "Invalid type syntax $s, please use ".
             "letter/digit/underscore only";
-        return [$s, $has_req ? {req=>1} : {}, {}];
+        return [$s, $has_req ? {req=>1} : {}];
 
     } elsif ($ref eq 'ARRAY') {
 
@@ -181,11 +183,11 @@ sub normalize_schema($) {
         if (defined $extras) {
             die "For array form with 3 elements, extras must be hash"
                 unless ref($extras) eq 'HASH';
-            die "'def' in extras must be a hash"
-                if exists $extras->{def} && ref($extras->{def}) ne 'HASH';
-            return [$t, $clset, { %{$extras} }];
+            die "Extras must be empty hashref (Sah 0.9.47)" if keys %$extras;
+            # we remove extras to comply with Sah 0.9.47+
+            return [$t, $clset];
         } else {
-            return [$t, $clset, {}];
+            return [$t, $clset];
         }
     }
 
@@ -207,20 +209,26 @@ Data::Sah::Normalize - Normalize Sah schema
 
 =head1 VERSION
 
-This document describes version 0.03 of Data::Sah::Normalize (from Perl distribution Data-Sah-Normalize), released on 2015-04-24.
+This document describes version 0.051 of Data::Sah::Normalize (from Perl distribution Data-Sah-Normalize), released on 2021-07-29.
 
 =head1 SYNOPSIS
 
  use Data::Sah::Normalize qw(normalize_clset normalize_schema);
 
  my $nclset = normalize_clset({'!a'=>1}); # -> {a=>1, 'a.op'=>'not'}
- my $nsch   = normalize_schema("int");    # -> ["int", {}, {}]
+ my $nsch   = normalize_schema("int");    # -> ["int", {}]
 
 =head1 DESCRIPTION
 
 This often-needed functionality is split from the main L<Data::Sah> to keep it
 in a small and minimal-dependencies package.
 
+=head1 CONTRIBUTOR
+
+=for stopwords Steven Haryanto
+
+Steven Haryanto <sharyanto@cpan.org>
+
 =head1 FUNCTIONS
 
 =head2 normalize_clset($clset) => HASH
@@ -235,15 +243,11 @@ C<of>).
 
 Normalize a Sah schema (scalar or array). Return an array. Produce a 2-level
 copy of schema, so it's safe to add/delete/modify the normalized schema's clause
-set and extras (but clause set's and extras' values are still references to the
-original). Die on failure.
+set, but clause set's values are still references to the original. Die on
+failure.
 
 TODO: recursively normalize clause which contains sah clauses (e.g. C<of>).
 
-=head1 SEE ALSO
-
-L<Sah>, L<Data::Sah>
-
 =head1 HOMEPAGE
 
 Please visit the project's homepage at L<https://metacpan.org/release/Data-Sah-Normalize>.
@@ -260,13 +264,17 @@ When submitting a bug or request, please include a test-file or a
 patch to an existing test-file that illustrates the bug or desired
 feature.
 
+=head1 SEE ALSO
+
+L<Sah>, L<Data::Sah>
+
 =head1 AUTHOR
 
 perlancar <perlancar@cpan.org>
 
 =head1 COPYRIGHT AND LICENSE
 
-This software is copyright (c) 2015 by perlancar@cpan.org.
+This software is copyright (c) 2021, 2018, 2015, 2014 by perlancar@cpan.org.
 
 This is free software; you can redistribute it and/or modify it under
 the same terms as the Perl 5 programming language system itself.
